/*
** mslide1t.c
**
** The skeleton slide maker program for Motif, using toolkit calls.
** Copyright (c) 1992 Sebern Engineering Inc.
*/

#include <stdio.h>
#include <stdlib.h>

#ifdef VMS
#pragma nostandard
#endif
#include <Xm/Xm.h>
#include <Xm/CascadeB.h>
#include <Xm/Form.h>
#include <Xm/MainW.h>
#include <Xm/PushB.h>
#include <Xm/RowColumn.h>
#ifdef VMS
#pragma standard
#endif

/*  Application context. */
static XtAppContext	app_context;

/*  Widget ID's */
static Widget		wid_top_level;
static Widget		wid_main;
static Widget		wid_menu_bar, wid_file_menu, wid_file_cascade,
			wid_edit_menu, wid_edit_cascade,
			wid_file_menu_new, wid_file_menu_open,
			wid_file_menu_save, wid_file_menu_save_as,
			wid_file_menu_quit,
			wid_edit_menu_display_slide,
			wid_entry_border_form;

/*  Function prototypes */
static void cb_exit (Widget w,
		     int *tag,
		     XmAnyCallbackStruct *callback_data);
static Widget make_menu_pb (Widget parent, String widname);

main (int argc, char *argv[])
{
    Boolean	    ok = True;
    Arg		    args [20];
    Cardinal	    ac;

    /* Initialize the toolkit and create the application shell.
	Set the shell resource that permits the shell to resize after
	it is created; some child widget resize requests might
	otherwise be refused. */
    ac = 0;
    XtSetArg (args[ac],XmNallowShellResize,True); ac++;
    wid_top_level = XtAppInitialize (&app_context,
				     "Mslide1t",
				     (XrmOptionDescList) NULL,
				     0,
    /* For X11R4, "(Cardinal *) &argc" may be required. */
				     &argc,
				     (String *) argv,
				     (String *) NULL,
				     args,
				     ac);

    /*	Create the main window widget. */
    wid_main = XmCreateMainWindow (wid_top_level,
				   "mslide_main",
				   (ArgList) NULL,
				   (Cardinal) 0);

    /*	Create and manage the menu bar. */
    wid_menu_bar = XmCreateMenuBar (wid_main,
				   "menu_bar",
				   (ArgList) NULL,
				   (Cardinal) 0);
    XtManageChild (wid_menu_bar);

    /*	Create the "File" pull-down menu and its cascade button
	in the menu bar. Note that, when creating a pull-down menu
	with the toolkit, the parent of the menu is the menu bar.
	In UIL, the parent would appear to be the cascade button,
	and UIL would take care of setting the XmNsubMenuId resource
	of the cascade button. Here, we must do it ourselves. */
    wid_file_menu = XmCreatePulldownMenu (wid_menu_bar,
				          "file_menu",
					  (ArgList) NULL,
					  (Cardinal) 0);
    ac = 0;
    XtSetArg (args[ac],XmNsubMenuId,wid_file_menu); ac++;
    wid_file_cascade = XmCreateCascadeButton (wid_menu_bar,
					      "file_cascade",
					      args,
					      ac);
    /*	We manage the cascade button, but not the menu. */
    XtManageChild (wid_file_cascade);

    /*	Create the "File" menu buttons. */
    wid_file_menu_new =
	make_menu_pb (wid_file_menu, "file_menu_new");
    wid_file_menu_open =
	make_menu_pb (wid_file_menu, "file_menu_open");
    wid_file_menu_save =
	make_menu_pb (wid_file_menu, "file_menu_save");
    wid_file_menu_save_as =
	make_menu_pb (wid_file_menu, "file_menu_save_as");

    /*	Create the "Quit" button and add an activate callback. */
    wid_file_menu_quit =
	make_menu_pb (wid_file_menu, "file_menu_quit");
    XtAddCallback (wid_file_menu_quit,
		   XmNactivateCallback,
		   (XtCallbackProc) cb_exit,
		   (caddr_t) 0);

    /*	Create the "Edit" menu and cascade button. */
    wid_edit_menu = XmCreatePulldownMenu (wid_menu_bar,
				          "edit_menu",
					  (ArgList) NULL,
					  (Cardinal) 0);
    ac = 0;
    XtSetArg (args[ac],XmNsubMenuId,wid_edit_menu); ac++;
    wid_edit_cascade = XmCreateCascadeButton (wid_menu_bar,
					      "edit_cascade",
					      args,
					      ac);
    XtManageChild (wid_edit_cascade);

    /*	Create the "Edit" menu button. */
    wid_edit_menu_display_slide =
	make_menu_pb (wid_edit_menu, "edit_menu_display_slide");

    /*	Create the main entry form. */
    ac = 0;
    XtSetArg (args[ac],XmNwidth,200); ac++;
    XtSetArg (args[ac],XmNheight,200); ac++;
    wid_entry_border_form = XmCreateForm (wid_main,
					  "entry_border_form",
					  args,
					  ac);
    XtManageChild (wid_entry_border_form);

    /*	Manage and realize the widget tree. */
    XtManageChild (wid_main);
    XtRealizeWidget (wid_top_level);

    /*	Start application processing. */
    XtAppMainLoop (app_context);

    /* Should not be able to reach this return. */
    return (0);
}


/*  The exit callback routine. */
static void cb_exit (Widget w,
		     int *tag,
		     XmAnyCallbackStruct *callback_data)
{
    exit (0);
}

/*  A utility routine to create and manage a pushbutton. */
static Widget make_menu_pb (Widget parent, String widname)
{
    Widget	    pb;

    /*	Create a push button with the specified parent and name. */
    pb = XmCreatePushButton (parent,
			     widname,
			     (ArgList) NULL,
			     (Cardinal) 0);

    /*	Manage the push button and return its ID. */
    XtManageChild (pb);
    return (pb);
}

